==> eiffelstudio-18.11.10.2592.tar: F_code/C6/lx277.c <==
/*
 * Code for class LX_SYMBOL_PARTITIONS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "lx277.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {LX_SYMBOL_PARTITIONS}.make */
void F925_5999 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {654,825,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F655_3185(RTCW(tr1), (EIF_BOOLEAN) 0, arg1, arg2);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	F924_5981(Current, arg1, arg2);
	RTLE;
}

/* {LX_SYMBOL_PARTITIONS}.initialize */
void F925_6000 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	F924_5982(Current);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F655_3223(RTCW(tr1));
	RTLE;
}

/* {LX_SYMBOL_PARTITIONS}.symbols */
EIF_REFERENCE F925_6001 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {LX_SYMBOL_PARTITIONS}.put */
void F925_6003 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F655_3209(RTCW(tr1), (EIF_BOOLEAN) 1, arg1);
	F924_5994(Current, arg1);
	RTLE;
}

/* {LX_SYMBOL_PARTITIONS}.add */
void F925_6004 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,loc6);
	RTLIU(3);
	
	RTGC;
	F924_5995(Current, arg1);
	loc3 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_4_2_0_1_);
	loc6 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tb1 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_4_0_);
	if (tb1) {
		loc2 = F924_5987(Current);
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
		loc4 = F924_5988(Current);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc3)) break;
			loc5 = F1059_6898(RTCW(arg1), loc1);
			loc2++;
			for (;;) {
				if ((EIF_BOOLEAN) (loc2 >= loc5)) break;
				F655_3209(RTCW(loc6), (EIF_BOOLEAN) 1, loc2);
				loc2++;
			}
			loc1++;
		}
		loc2++;
		for (;;) {
			if ((EIF_BOOLEAN) (loc2 > loc4)) break;
			F655_3209(RTCW(loc6), (EIF_BOOLEAN) 1, loc2);
			loc2++;
		}
	} else {
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc3)) break;
			ti4_1 = F1059_6898(RTCW(arg1), loc1);
			F655_3209(RTCW(loc6), (EIF_BOOLEAN) 1, ti4_1);
			loc1++;
		}
	}
	RTLE;
}

void EIF_Minit277 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/lx277.c <==
/*
 * Code for class LX_SYMBOL_PARTITIONS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "lx277.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {LX_SYMBOL_PARTITIONS}.make */
void F929_6025 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,654,825,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F655_3195(RTCW(tr1), (EIF_BOOLEAN) 0, arg1, arg2);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	F928_6007(Current, arg1, arg2);
	RTLE;
}

/* {LX_SYMBOL_PARTITIONS}.initialize */
void F929_6026 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	F928_6008(Current);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F655_3233(RTCW(tr1));
	RTLE;
}

/* {LX_SYMBOL_PARTITIONS}.put */
void F929_6029 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F655_3219(RTCW(tr1), (EIF_BOOLEAN) 1, arg1);
	F928_6020(Current, arg1);
	RTLE;
}

/* {LX_SYMBOL_PARTITIONS}.add */
void F929_6030 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,loc6);
	RTLIU(3);
	
	RTGC;
	F928_6021(Current, arg1);
	loc3 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_4_2_0_1_);
	loc6 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tb1 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_4_0_);
	if (tb1) {
		loc2 = F928_6013(Current);
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
		loc4 = F928_6014(Current);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc3)) break;
			loc5 = F1064_6930(RTCW(arg1), loc1);
			loc2++;
			for (;;) {
				if ((EIF_BOOLEAN) (loc2 >= loc5)) break;
				F655_3219(RTCW(loc6), (EIF_BOOLEAN) 1, loc2);
				loc2++;
			}
			loc1++;
		}
		loc2++;
		for (;;) {
			if ((EIF_BOOLEAN) (loc2 > loc4)) break;
			F655_3219(RTCW(loc6), (EIF_BOOLEAN) 1, loc2);
			loc2++;
		}
	} else {
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc3)) break;
			ti4_1 = F1064_6930(RTCW(arg1), loc1);
			F655_3219(RTCW(loc6), (EIF_BOOLEAN) 1, ti4_1);
			loc1++;
		}
	}
	RTLE;
}

void EIF_Minit277 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
